// Copyright (c) 2007 Helsinki Institute of Information Technology HIIT
// 
// Permission is hereby granted, free of charge, to any person
// obtaining a copy of this software and associated documentation
// files (the "Software"), to deal in the Software without
// restriction, including without limitation the rights to use,
// copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the
// Software is furnished to do so, subject to the following
// conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
// OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
// FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
// OTHER DEALINGS IN THE SOFTWARE.

using System;
using System.Collections.Generic;
using System.Text;

namespace Gazillion
{
    public class FixationBag
    {
        IList<string> words;
        IList<int> msecTotal;
        IList<int> fixationCounts;
        int current;

        public FixationBag()
        {
            this.words = new List<string>();
            this.msecTotal = new List<int>();
            this.fixationCounts = new List<int>();
            this.current = 0;
        }


        public void Add(string word, int msec, int fixations)
        {
            word = word.Trim();
            if (word.Length == 0 || msec < 1 || fixations < 1)
                return;
            this.words.Add(word);
            this.msecTotal.Add(msec);
            this.fixationCounts.Add(fixations);
            ++this.current;
        }

        public string GetWord(int id)
        {
            if (id < 0 || id >= this.current)
            {
                throw new ArgumentException("Fixation record out of range");
            }
            return this.words[id];
        }

        public int GetMsec(int id)
        {
            if (id < 0 || id >= this.current)
            {
                throw new ArgumentException("Fixation record out of range");
            }
            return this.msecTotal[id];
        }

        public int GetFixations(int id)
        {
            if (id < 0 || id >= this.current)
            {
                throw new ArgumentException("Fixation record out of range");
            }
            return this.fixationCounts[id];
        }

        public int Count()
        {
            return this.current;
        }



    }
}
